@@ -18,6 +18,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <glib/gi18n.h>
 #include "appearance.h"
 #include "appearance-desktop.h"
 #include "appearance-font.h"
@@ -29,26 +30,16 @@
 #include "activate-settings-daemon.h"
 #include "capplet-util.h"
 
-/* required for gnome_program_init(): */
-#include <libgnome/libgnome.h>
-#include <libgnomeui/gnome-ui-init.h>
-/* ---------------------------------- */
-#include <libgnomeui/gnome-thumbnail.h>
-
 static AppearanceData *
-init_appearance_data (int *argc, char ***argv)
+init_appearance_data (int *argc, char ***argv, GOptionContext *context)
 {
   AppearanceData *data = NULL;
   gchar *gladefile;
   GladeXML *ui;
 
-  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-  textdomain (GETTEXT_PACKAGE);
-
   g_thread_init (NULL);
   theme_thumbnail_factory_init (*argc, *argv);
-  gtk_init (argc, argv);
+  capplet_init (context, argc, argv);
   activate_settings_daemon ();
 
   /* set up the data */
@@ -60,7 +51,7 @@ init_appearance_data (int *argc, char ***argv)
     data = g_new (AppearanceData, 1);
     data->client = gconf_client_get_default ();
     data->xml = ui;
-    data->thumb_factory = gnome_thumbnail_factory_new (GNOME_THUMBNAIL_SIZE_NORMAL);
+    data->thumb_factory = gnome_desktop_thumbnail_factory_new (GNOME_DESKTOP_THUMBNAIL_SIZE_NORMAL);
   }
 
   return data;
@@ -85,13 +76,39 @@ main_window_response (GtkWidget *widget,
     g_object_unref (data->client);
     g_object_unref (data->xml);
   }
+  else if (response_id == GTK_RESPONSE_HELP)
+  {
+      GtkNotebook *nb;
+      gint pindex;
+
+      nb = GTK_NOTEBOOK (glade_xml_get_widget (data->xml, "main_notebook"));
+      pindex = gtk_notebook_get_current_page (nb);
+
+      switch (pindex)
+      {
+        case 0: /* theme */
+          capplet_help (GTK_WINDOW (widget), "goscustdesk-12");
+          break;
+        case 1: /* background */
+          capplet_help (GTK_WINDOW (widget), "goscustdesk-7");
+          break;
+        case 2: /* fonts */
+          capplet_help (GTK_WINDOW (widget), "goscustdesk-38");
+          break;
+        case 3: /* interface */
+          capplet_help (GTK_WINDOW (widget), "goscustuserinter-2");
+          break;
+        default:
+          capplet_help (GTK_WINDOW (widget), "prefs-look-and-feel");
+          break;
+       }
+  }
 }
 
 int
 main (int argc, char **argv)
 {
   AppearanceData *data;
-  GnomeProgram *program;
   GtkWidget *w;
 
   gchar *install_filename = NULL;
@@ -124,23 +141,13 @@ main (int argc, char **argv)
       { NULL }
     };
 
-  /* init */
-  data = init_appearance_data (&argc, &argv);
-  if (!data)
-    return 1;
-
   option_context = g_option_context_new (NULL);
   g_option_context_add_main_entries (option_context, option_entries, GETTEXT_PACKAGE);
 
-  /* this appears to be required for gnome_wm_manager_init (), which is called
-   * inside gnome_meta_theme_set ();
-   * TODO: try to remove if possible
-   */
-  program = gnome_program_init ("appearance", VERSION,
-        LIBGNOMEUI_MODULE, argc, argv,
-        GNOME_PARAM_APP_DATADIR, GNOMECC_DATA_DIR,
-        GNOME_PARAM_GOPTION_CONTEXT, option_context,
-        NULL);
+  /* init */
+  data = init_appearance_data (&argc, &argv, option_context);
+  if (!data)
+    return 1;
 
   if (install_filename != NULL) {
     GFile *inst = g_file_new_for_commandline_arg (install_filename);
@@ -188,12 +195,13 @@ main (int argc, char **argv)
     g_free (page_name);
   }
 
+  g_option_context_free (option_context);
+
   /* start the mainloop */
   gtk_main ();
 
   /* free stuff */
   g_free (data);
-  g_object_unref (program);
 
   return 0;
 }
