@@ -21,11 +21,13 @@
 
 #include <string.h>
 #include <pango/pango.h>
+#include <glib/gi18n.h>
 
 #include "theme-util.h"
 #include "gtkrc-utils.h"
 #include "gconf-property-editor.h"
 #include "theme-thumbnail.h"
+#include "capplet-util.h"
 #include "gedit-message-area.h"
 
 typedef void (* ThumbnailGenFunc) (void               *type,
@@ -392,7 +394,7 @@ static void
 style_response_cb (GtkDialog *dialog, gint response_id)
 {
   if (response_id == GTK_RESPONSE_HELP) {
-    /* FIXME: help */
+    capplet_help (GTK_WINDOW (dialog), "goscustdesk-61");
   } else {
     gtk_widget_hide (GTK_WIDGET (dialog));
   }
@@ -791,19 +793,20 @@ create_thumbnail (const gchar *name, GdkPixbuf *default_thumb, AppearanceData *d
 static void
 changed_on_disk_cb (GnomeThemeCommonInfo *theme,
 		    GnomeThemeChangeType  change_type,
+                    GnomeThemeElement     element_type,
 		    AppearanceData       *data)
 {
   if (theme->type == GNOME_THEME_TYPE_REGULAR) {
     GnomeThemeInfo *info = (GnomeThemeInfo *) theme;
 
     if (change_type == GNOME_THEME_CHANGE_DELETED) {
-      if (info->has_gtk)
+      if (element_type & GNOME_THEME_GTK_2)
         remove_from_treeview ("gtk_themes_list", info->name, data);
-      if (info->has_metacity)
+      if (element_type & GNOME_THEME_METACITY)
         remove_from_treeview ("window_themes_list", info->name, data);
 
     } else {
-      if (info->has_gtk) {
+      if (element_type & GNOME_THEME_GTK_2) {
         if (change_type == GNOME_THEME_CHANGE_CREATED)
           add_to_treeview ("gtk_themes_list", info->name, info->name, data->gtk_theme_icon, data);
         else if (change_type == GNOME_THEME_CHANGE_CHANGED)
@@ -813,7 +816,7 @@ changed_on_disk_cb (GnomeThemeCommonInfo *theme,
             (ThemeThumbnailFunc) gtk_theme_thumbnail_cb, data, NULL);
       }
 
-      if (info->has_metacity) {
+      if (element_type & GNOME_THEME_METACITY) {
         if (change_type == GNOME_THEME_CHANGE_CREATED)
           add_to_treeview ("window_themes_list", info->name, info->name, data->window_theme_icon, data);
         else if (change_type == GNOME_THEME_CHANGE_CHANGED)
