@@ -22,16 +22,14 @@
 
 #include <glib/gi18n.h>
 #include <gconf/gconf-client.h>
-#include <gnome.h>
 #include <string.h>
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include "gnome-wp-item.h"
 
 static GConfEnumStringPair options_lookup[] = {
   { GNOME_BG_PLACEMENT_CENTERED, "centered" },
   { GNOME_BG_PLACEMENT_FILL_SCREEN, "stretched" },
   { GNOME_BG_PLACEMENT_SCALED, "scaled" },
-  { GNOME_BG_PLACEMENT_ZOOMED, "zoomed" },
+  { GNOME_BG_PLACEMENT_ZOOMED, "zoom" },
   { GNOME_BG_PLACEMENT_TILED, "wallpaper" },
   { 0, NULL }
 };
@@ -70,7 +68,7 @@ GnomeBGColorType wp_item_string_to_shading (const gchar *shade_type)
 static void set_bg_properties (GnomeWPItem *item)
 {
   if (item->filename)
-    gnome_bg_set_uri (item->bg, item->filename);
+    gnome_bg_set_filename (item->bg, item->filename);
 
   gnome_bg_set_color (item->bg, item->shade_type, item->pcolor, item->scolor);
   gnome_bg_set_placement (item->bg, item->options);
@@ -126,23 +124,21 @@ void gnome_wp_item_update (GnomeWPItem *item) {
 
 GnomeWPItem * gnome_wp_item_new (const gchar * filename,
 				 GHashTable * wallpapers,
-				 GnomeThumbnailFactory * thumbnails) {
+				 GnomeDesktopThumbnailFactory * thumbnails) {
   GnomeWPItem *item = g_new0 (GnomeWPItem, 1);
 
-  item->filename = gnome_vfs_unescape_string_for_display (filename);
+  item->filename = g_strdup (filename);
+  item->fileinfo = gnome_wp_info_new (filename, thumbnails);
 
-  item->fileinfo = gnome_wp_info_new (item->filename, thumbnails);
-
-  if (item->fileinfo != NULL &&
+  if (item->fileinfo != NULL && item->fileinfo->mime_type != NULL &&
       (g_str_has_prefix (item->fileinfo->mime_type, "image/") ||
        strcmp (item->fileinfo->mime_type, "application/xml") == 0)) {
-    if (item->name == NULL) {
-      if (g_utf8_validate (item->fileinfo->name, -1, NULL))
-	item->name = g_strdup (item->fileinfo->name);
-      else
-	item->name = g_filename_to_utf8 (item->fileinfo->name, -1, NULL,
-					 NULL, NULL);
-    }
+
+    if (g_utf8_validate (item->fileinfo->name, -1, NULL))
+      item->name = g_strdup (item->fileinfo->name);
+    else
+      item->name = g_filename_to_utf8 (item->fileinfo->name, -1, NULL,
+				       NULL, NULL);
 
     gnome_wp_item_update (item);
     gnome_wp_item_update_description (item);
@@ -184,7 +180,7 @@ void gnome_wp_item_free (GnomeWPItem * item) {
 #define LIST_IMAGE_WIDTH 108
 
 GdkPixbuf * gnome_wp_item_get_thumbnail (GnomeWPItem * item,
-					 GnomeThumbnailFactory * thumbs) {
+					 GnomeDesktopThumbnailFactory * thumbs) {
   GdkPixbuf *pixbuf;
   double aspect =
     (double)gdk_screen_get_height (gdk_screen_get_default()) /
@@ -211,7 +207,7 @@ void gnome_wp_item_update_description (GnomeWPItem * item) {
     if (strcmp (item->fileinfo->mime_type, "application/xml") == 0)
       description = _("Slide Show");
     else
-      description = gnome_vfs_mime_get_description (item->fileinfo->mime_type);
+      description = g_content_type_get_description (item->fileinfo->mime_type);
 
     /* translators: <b>wallpaper name</b>
      * mime type, x pixel(s) by y pixel(s)
