@@ -27,6 +27,7 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <glib/gstdio.h>
+#include <unistd.h>
 
 #include "capplet-util.h"
 #include "file-transfer-dialog.h"
@@ -83,6 +84,7 @@ file_theme_type (const gchar *dir)
 		gboolean match;
 
 		g_file_get_contents (filename, &file_contents, &file_size, NULL);
+		g_free (filename);
 
 		pattern = g_pattern_spec_new ("*[Icon Theme]*");
 		match = g_pattern_match_string (pattern, file_contents);
@@ -157,7 +159,7 @@ transfer_cancel_cb (GtkWidget *dlg, gchar *path)
 	GFile *todelete;
 
 	todelete = g_file_new_for_path (path);
-	g_file_delete (todelete, NULL, NULL);
+	capplet_file_delete_recursive (todelete, NULL);
 
 	g_object_unref (todelete);
 	g_free (path);
@@ -249,7 +251,7 @@ invalid_theme_dialog (const gchar *filename, gboolean maybe_theme_engine)
 	const gchar *engine = _("\"%s\" does not appear to be a valid theme. It may be a theme engine which you need to compile.");
 
 	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
-			GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, primary);
+			GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", primary);
 	if (maybe_theme_engine)
 		gtk_message_dialog_format_secondary_text (
 				GTK_MESSAGE_DIALOG (dialog), engine, filename);
@@ -268,7 +270,6 @@ gnome_theme_install_real (gint filetype, const gchar *tmp_dir, const gchar *them
 	GFile *theme_source_dir, *theme_dest_dir;
 	GError *error = NULL;
 	gint theme_type;
-	gchar *user_message = NULL;
 	gchar *target_dir = NULL;
 
 	/* What type of theme is it? */
@@ -285,8 +286,6 @@ gnome_theme_install_real (gint filetype, const gchar *tmp_dir, const gchar *them
 		target_dir = g_build_path (G_DIR_SEPARATOR_S,
 					   g_get_home_dir (), ".themes",
 			 		   theme_name, NULL);
-		user_message = g_strdup_printf (_("GNOME Theme %s correctly installed"),
-						theme_name);
 		break;
 	case THEME_METACITY:
 	case THEME_GTK:
@@ -357,9 +356,10 @@ gnome_theme_install_real (gint filetype, const gchar *tmp_dir, const gchar *them
 					GTK_DIALOG_MODAL,
 					GTK_MESSAGE_ERROR,
 					GTK_BUTTONS_OK,
+					"%s",
 					str);
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-							  error->message);
+							  "%s", error->message);
 
 		g_free (str);
 		g_error_free (error);
@@ -383,19 +383,18 @@ gnome_theme_install_real (gint filetype, const gchar *tmp_dir, const gchar *them
 		if (ask_user)
 		{
 			/* Ask to apply theme (if we can) */
-			if ((theme_type == THEME_GTK || theme_type == THEME_METACITY ||
+			if (theme_type == THEME_GTK || theme_type == THEME_METACITY ||
 			    theme_type == THEME_ICON || theme_type == THEME_CURSOR ||
-			    theme_type == THEME_ICON_CURSOR) && ask_user)
+			    theme_type == THEME_ICON_CURSOR)
 			{
 				/* TODO: currently cannot apply "gnome themes" */
 				gchar *str;
 
 				str = g_strdup_printf (_("The theme \"%s\" has been installed."), theme_name);
-				user_message = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>", str);
+				dialog = gtk_message_dialog_new_with_markup (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_NONE,
+									     "<span weight=\"bold\" size=\"larger\">%s</span>", str);
 				g_free (str);
 
-				dialog = gtk_message_dialog_new_with_markup (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_NONE, user_message);
-
 				gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), _("Would you like to apply it now, or keep your current theme?"));
 
 				gtk_dialog_add_button (GTK_DIALOG (dialog), _("Keep Current Theme"), GTK_RESPONSE_CLOSE);
@@ -444,14 +443,14 @@ gnome_theme_install_real (gint filetype, const gchar *tmp_dir, const gchar *them
 				       GTK_DIALOG_MODAL,
 				       GTK_MESSAGE_INFO,
 				       GTK_BUTTONS_OK,
-				       user_message);
+				       _("GNOME Theme %s correctly installed"),
+				       theme_name);
 				gtk_dialog_run (GTK_DIALOG (dialog));
 			}
 			gtk_widget_destroy (dialog);
 		}
 	}
 
-	g_free (user_message);
 	g_free (target_dir);
 
 	return success;
