@@ -25,16 +25,17 @@
 #  include <config.h>
 #endif
 
-#include <gnome.h>
 #include <gconf/gconf-client.h>
 #include <glade/glade.h>
-
-#include "capplet-util.h"
+#include <glib/gi18n.h>
 
 #include <libgnomekbd/gkbd-desktop-config.h>
+#include <libgnomekbd/gkbd-keyboard-drawing.h>
 
+#include "capplet-util.h"
 #include "gnome-keyboard-properties-xkb.h"
 
+
 #define SEL_LAYOUT_TREE_COL_DESCRIPTION 0
 #define SEL_LAYOUT_TREE_COL_DEFAULT 1
 #define SEL_LAYOUT_TREE_COL_ID 2
@@ -179,6 +180,7 @@ static void
 xkb_layouts_enable_disable_buttons (GladeXML * dialog)
 {
 	GtkWidget *add_layout_btn = WID ("xkb_layouts_add");
+	GtkWidget *print_layout_btn = WID ("xkb_layouts_print");
 	GtkWidget *del_layout_btn = WID ("xkb_layouts_remove");
 	GtkWidget *selected_layouts_tree = WID ("xkb_layouts_selected");
 
@@ -202,18 +204,47 @@ xkb_layouts_enable_disable_buttons (GladeXML * dialog)
 				   || max_selected_layouts == 0));
 	gtk_widget_set_sensitive (del_layout_btn, (n_selected_layouts > 1)
 				  && (n_selected_selected_layouts > 0));
+	gtk_widget_set_sensitive (print_layout_btn,
+				  (n_selected_selected_layouts > 0));
+}
+
+static GtkTreeViewColumn *
+xkb_layouts_create_default_layout_column ()
+{
+	GtkTreeViewColumn *def_column =
+	    gtk_tree_view_column_new_with_attributes (_("Default"),
+						      toggle_renderer,
+						      "active",
+						      SEL_LAYOUT_TREE_COL_DEFAULT,
+						      NULL);
+	gtk_tree_view_column_set_sizing (def_column,
+					 GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+	gtk_tree_view_column_set_resizable (def_column, TRUE);
+	gtk_tree_view_column_set_expand (def_column, FALSE);
+	return def_column;
 }
 
 void
 xkb_layouts_enable_disable_default (GladeXML * dialog, gboolean enable)
 {
-	GValue val = { 0 };
 	GtkWidget *tree_view = WID ("xkb_layouts_selected");
 
-	g_value_init (&val, G_TYPE_BOOLEAN);
-	g_value_set_boolean (&val, enable);
-	g_object_set_property (G_OBJECT (toggle_renderer), "activatable",
-			       &val);
+	if (enable) {
+		gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view),
+					     xkb_layouts_create_default_layout_column
+					     ());
+		g_object_unref (toggle_renderer);
+	} else {
+		GtkTreeViewColumn *col =
+		    gtk_tree_view_get_column (GTK_TREE_VIEW (tree_view),
+					      1);
+		if (col != NULL) {
+			g_object_ref (toggle_renderer);
+			gtk_tree_view_column_clear (col);
+			gtk_tree_view_remove_column (GTK_TREE_VIEW
+						     (tree_view), col);
+		}
+	}
 
 	gtk_widget_draw (tree_view, NULL);
 }
@@ -223,7 +254,7 @@ xkb_layouts_dnd_data_get (GtkWidget * widget, GdkDragContext * dc,
 			  GtkSelectionData * selection_data, guint info,
 			  guint t, GladeXML * dialog)
 {
-	/* Storing the value into selection - 
+	/* Storing the value into selection -
 	 * while it is actually not used
 	 */
 	gint idx = find_selected_layout_idx (dialog);
@@ -244,13 +275,17 @@ xkb_layouts_dnd_data_received (GtkWidget * widget, GdkDragContext * dc,
 	GtkTreeViewDropPosition pos;
 	gint didx;
 	gchar *id;
-	GSList *layouts_list = xkb_layouts_get_selected_list ();
-	GSList *node2Remove = g_slist_nth (layouts_list, sidx);
+	GSList *layouts_list;
+	GSList *node2Remove;
 
-	layouts_list = g_slist_remove_link (layouts_list, node2Remove);
+	if (sidx == -1)
+		return;
+
+	layouts_list = xkb_layouts_get_selected_list ();
+	node2Remove = g_slist_nth (layouts_list, sidx);
 
 	id = (gchar *) node2Remove->data;
-	g_slist_free_1 (node2Remove);
+	layouts_list = g_slist_delete_link (layouts_list, node2Remove);
 
 	if (!gtk_tree_view_get_dest_row_at_pos
 	    (GTK_TREE_VIEW (tree_view), x, y, &path, &pos)) {
@@ -282,16 +317,17 @@ xkb_layouts_prepare_selected_tree (GladeXML * dialog,
 	    gtk_list_store_new (3, G_TYPE_STRING, G_TYPE_BOOLEAN,
 				G_TYPE_STRING);
 	GtkWidget *tree_view = WID ("xkb_layouts_selected");
-	GtkTreeViewColumn *desc_column, *def_column;
 	GtkTreeSelection *selection;
 	GtkTargetEntry self_drag_target =
 	    { "xkb_layouts_selected", GTK_TARGET_SAME_WIDGET, 0 };
+	GtkTreeViewColumn *desc_column;
 
 	text_renderer = GTK_CELL_RENDERER (gtk_cell_renderer_text_new ());
 	toggle_renderer =
 	    GTK_CELL_RENDERER (gtk_cell_renderer_toggle_new ());
 	gtk_cell_renderer_toggle_set_radio (GTK_CELL_RENDERER_TOGGLE
 					    (toggle_renderer), TRUE);
+	g_object_ref (toggle_renderer);
 
 	desc_column =
 	    gtk_tree_view_column_new_with_attributes (_("Layout"),
@@ -299,12 +335,6 @@ xkb_layouts_prepare_selected_tree (GladeXML * dialog,
 						      "text",
 						      SEL_LAYOUT_TREE_COL_DESCRIPTION,
 						      NULL);
-	def_column =
-	    gtk_tree_view_column_new_with_attributes (_("Default"),
-						      toggle_renderer,
-						      "active",
-						      SEL_LAYOUT_TREE_COL_DEFAULT,
-						      NULL);
 	selection =
 	    gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
 
@@ -313,17 +343,11 @@ xkb_layouts_prepare_selected_tree (GladeXML * dialog,
 
 	gtk_tree_view_column_set_sizing (desc_column,
 					 GTK_TREE_VIEW_COLUMN_AUTOSIZE);
-	gtk_tree_view_column_set_sizing (def_column,
-					 GTK_TREE_VIEW_COLUMN_AUTOSIZE);
 	gtk_tree_view_column_set_resizable (desc_column, TRUE);
-	gtk_tree_view_column_set_resizable (def_column, TRUE);
 	gtk_tree_view_column_set_expand (desc_column, TRUE);
-	gtk_tree_view_column_set_expand (def_column, FALSE);
 
 	gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view),
 				     desc_column);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view),
-				     def_column);
 
 	g_signal_connect_swapped (G_OBJECT (selection), "changed",
 				  G_CALLBACK
@@ -347,9 +371,20 @@ xkb_layouts_prepare_selected_tree (GladeXML * dialog,
 			   &self_drag_target, 1, GDK_ACTION_MOVE);
 
 	g_signal_connect (G_OBJECT (tree_view), "drag_data_get",
-			    G_CALLBACK (xkb_layouts_dnd_data_get), dialog);
+			  G_CALLBACK (xkb_layouts_dnd_data_get), dialog);
 	g_signal_connect (G_OBJECT (tree_view), "drag_data_received",
-			    G_CALLBACK (xkb_layouts_dnd_data_received), dialog);
+			  G_CALLBACK (xkb_layouts_dnd_data_received),
+			  dialog);
+}
+
+gchar *
+xkb_layout_description_utf8 (const gchar * visible)
+{
+	char *l, *sl, *v, *sv;
+	if (gkbd_keyboard_config_get_descriptions
+	    (config_registry, visible, &sl, &l, &sv, &v))
+		visible = gkbd_keyboard_config_format_full_layout (l, v);
+	return g_strstrip (g_strdup (visible));
 }
 
 void
@@ -372,18 +407,9 @@ xkb_layouts_fill_selected_tree (GladeXML * dialog)
 	for (cur_layout = layouts; cur_layout != NULL;
 	     cur_layout = cur_layout->next) {
 		GtkTreeIter iter;
-		char *l, *sl, *v, *sv;
-		char *v1, *utf_visible;
 		const char *visible = (char *) cur_layout->data;
+		gchar *utf_visible = xkb_layout_description_utf8 (visible);
 		gtk_list_store_append (list_store, &iter);
-		if (gkbd_keyboard_config_get_descriptions
-		    (config_registry, visible, &sl, &l, &sv, &v))
-			visible =
-			    gkbd_keyboard_config_format_full_layout (l, v);
-		v1 = g_strdup (visible);
-		utf_visible =
-		    g_locale_to_utf8 (g_strstrip (v1), -1, NULL, NULL,
-				      NULL);
 		gtk_list_store_set (list_store, &iter,
 				    SEL_LAYOUT_TREE_COL_DESCRIPTION,
 				    utf_visible,
@@ -391,7 +417,6 @@ xkb_layouts_fill_selected_tree (GladeXML * dialog)
 				    SEL_LAYOUT_TREE_COL_ID,
 				    cur_layout->data, -1);
 		g_free (utf_visible);
-		g_free (v1);
 	}
 
 	clear_xkb_elements_list (layouts);
@@ -432,6 +457,32 @@ add_selected_layout (GtkWidget * button, GladeXML * dialog)
 	xkb_layout_choose (dialog);
 }
 
+static void
+print_selected_layout (GtkWidget * button, GladeXML * dialog)
+{
+	gint idx = find_selected_layout_idx (dialog);
+
+	if (idx != -1) {
+		GSList *layouts_list = xkb_layouts_get_selected_list ();
+		const gchar *id = g_slist_nth_data (layouts_list, idx);
+		char *descr = xkb_layout_description_utf8 (id);
+
+		GtkWidget *window = WID ("keyboard_dialog");
+		GtkWidget *kbdraw =
+		    xkb_layout_preview_create_widget (NULL);
+		g_object_ref_sink (kbdraw);
+		gtk_widget_set_parent (kbdraw, window);
+		xkb_layout_preview_set_drawing_layout (kbdraw, id);
+		gkbd_keyboard_drawing_print (GKBD_KEYBOARD_DRAWING
+					     (kbdraw), GTK_WINDOW (window),
+					     descr);
+		g_object_unref (kbdraw);
+		g_free (descr);
+
+		clear_xkb_elements_list (layouts_list);
+	}
+}
+
 static void
 remove_selected_layout (GtkWidget * button, GladeXML * dialog)
 {
@@ -464,6 +515,8 @@ xkb_layouts_register_buttons_handlers (GladeXML * dialog)
 {
 	g_signal_connect (G_OBJECT (WID ("xkb_layouts_add")), "clicked",
 			  G_CALLBACK (add_selected_layout), dialog);
+	g_signal_connect (G_OBJECT (WID ("xkb_layouts_print")), "clicked",
+			  G_CALLBACK (print_selected_layout), dialog);
 	g_signal_connect (G_OBJECT (WID ("xkb_layouts_remove")), "clicked",
 			  G_CALLBACK (remove_selected_layout), dialog);
 }
